==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/pt_BR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Espaço",
    "Unknown" : "Desconhecido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "Não comparecer",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), caindo de volta para UTC",
    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
    "New event" : "Novo evento",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetindo",
    "When shared show full event" : "Quando compartilhado mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado esconder este evento",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Please add a title!" : "Por favor adicione um título!",
    "Please select a calendar!" : "Por favor selecione um calendário!",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Todos os dias",
    "Every week" : "Toda semana",
    "Every month" : "Todo mês",
    "Every year" : "Todo ano",
    "never" : "nunca",
    "after" : "após",
    "At time of event" : "No momento do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizadas",
    "Audio" : "Audio",
    "E Mail" : "E Mail",
    "Pop up" : "Pop up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "início",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Lembretes de edição de tipos desconhecidos não são suportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importada com sucesso",
    "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
    "Partially imported, {n} failures" : "Parcialmente importada, {n} falha",
    "Audio alarm" : "Alarme sonoro",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "{type} {time} after the event starts" : "{type} {time} depois dos eventos iniciarem",
    "{type} {time} after the event ends" : "{type} {time} após o término do evento",
    "{type} at the event's start" : "{type} no início do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "{type} at {time}" : "{type} em {time}",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Title of the Event" : "Título do evento",
    "starts" : "Inícios",
    "ends" : "Finais",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "More ..." : "Mais ...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Event status" : "Status do evento",
    "Visibility when sharing" : "Visível quando compartilhando",
    "Export" : "Exportar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug a montante, o calendário não é atualmente capaz de fornecer suporte para o recurso de pipeline ativo.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e pedir-lhes para desativar a opção de configuração \"asset-pipeline.enabled\".",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão quebrados. Por favor, verifique o console JS para mais informações.",
    "Share Calendar" : "Compartilhar Calendário",
    "Shared" : "Compartilhado",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Link",
    "Download" : "Baixar",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "can edit" : "pode editar",
    "group" : "grupo",
    "New Calendar" : "Novo Calendário",
    "Subscriptions" : "Inscrições",
    "New Subscription" : "Nova Subscrição",
    "Url" : "Url",
    "Edit event" : "Editar evento",
    "Delete Event" : "Apagar Evento",
    "Save Event" : "Salvar Evento",
    "Time" : "Horário",
    "Type" : "Digite",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes sempre",
    "Add" : "Adicionar",
    "E-Mail address of attendee" : "Endereço de email do participante",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de email nas configurações pessoais, a fim de adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Regra de repetição de evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados com atualizações subsequentes.",
    "Reset repeating rule" : "Reiniciar regra de repetição",
    "Repeat every ..." : "Repetir a cada ...",
    "end repeat ..." : "fim da repetição ...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "Analisando calendário",
    "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "Import scheduled" : "Importar agendados",
    "Settings" : "Configurações",
    "Skip simple event editor" : "Pular editor de eventos simples",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
    "Primary CalDAV address" : "Endereço CalDAV primário",
    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV "
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-calendar-1%3A1.4.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/pt_BR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Espaço",
    "Unknown" : "Desconhecido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "Não comparecer",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), caindo de volta para UTC",
    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
    "New event" : "Novo evento",
    "CalDAV address for clients" : "Endereço CalDAV para clients",
    "Error saving WebCal-calendar" : "Erro salvando o WebCal-calendário",
    "WebDAV address for subscriptions" : "Endereço WebDAV para inscrições",
    "EMail has been sent." : "E-mail enviado",
    "There was an issue while sending your EMail." : "Houve um erro ao enviar o E-mail",
    "group" : "grupo",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetindo",
    "When shared show full event" : "Quando compartilhado mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado esconder este evento",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Please add a title!" : "Por favor adicione um título!",
    "Please select a calendar!" : "Por favor selecione um calendário!",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Todos os dias",
    "Every week" : "Toda semana",
    "Every month" : "Todo mês",
    "Every year" : "Todo ano",
    "never" : "nunca",
    "after" : "após",
    "At time of event" : "No momento do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizadas",
    "Audio" : "Audio",
    "E Mail" : "E Mail",
    "Pop up" : "Pop up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "início",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Lembretes de edição de tipos desconhecidos não são suportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importada com sucesso",
    "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
    "Partially imported, {n} failures" : "Parcialmente importada, {n} falha",
    "Audio alarm" : "Alarme sonoro",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "{type} {time} after the event starts" : "{type} {time} depois dos eventos iniciarem",
    "{type} {time} after the event ends" : "{type} {time} após o término do evento",
    "{type} at the event's start" : "{type} no início do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "{type} at {time}" : "{type} em {time}",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
    "Title of the Event" : "Título do evento",
    "starts" : "Inícios",
    "ends" : "Finais",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "More ..." : "Mais ...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Event status" : "Status do evento",
    "Visibility when sharing" : "Visível quando compartilhando",
    "Export" : "Exportar",
    "Hello," : "Ola,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisa-lo que %s publicou um calendário {boldstart}%s{boldend}",
    "Click here to access it" : "Clique aqui para acessar",
    "Cheers!" : "Saúde!",
    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisa-lo que %s publicou um calendário %s.",
    "Click on the link below to access it" : "Clique no link abaixo para acessar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug a montante, o calendário não é atualmente capaz de fornecer suporte para o recurso de pipeline ativo.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e pedir-lhes para desativar a opção de configuração \"asset-pipeline.enabled\".",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão quebrados. Por favor, verifique o console JS para mais informações.",
    "Share Calendar" : "Compartilhar Calendário",
    "Shared" : "Compartilhado",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Link",
    "WebCal URL" : "WebCal URL",
    "Download" : "Baixar",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "can edit" : "pode editar",
    "Share link" : "Compartilhar link",
    "Public access" : "Acesso publico",
    "Email link to person" : "Link via E-mail para pessoa",
    "Send" : "Enviar",
    "New Calendar" : "Novo Calendário",
    "Name" : "Nome",
    "New Subscription" : "Nova Subscrição",
    "WebCal-URL" : "WebCal-URL",
    "Go back" : "Voltar",
    "Go forward" : "Avançar",
    "Edit event" : "Editar evento",
    "Delete Event" : "Apagar Evento",
    "Save Event" : "Salvar Evento",
    "Time" : "Horário",
    "Type" : "Digite",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes sempre",
    "Add" : "Adicionar",
    "E-Mail address of attendee" : "Endereço de email do participante",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de email nas configurações pessoais, a fim de adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Regra de repetição de evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados com atualizações subsequentes.",
    "Reset repeating rule" : "Reiniciar regra de repetição",
    "Repeat every ..." : "Repetir a cada ...",
    "end repeat ..." : "fim da repetição ...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "Analisando calendário",
    "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "Import scheduled" : "Importar agendados",
    "Settings" : "Configurações",
    "Publish URL" : "Publicar URL",
    "Iframe to integrate" : "frame para integrar",
    "Skip simple event editor" : "Pular editor de eventos simples",
    "Show week numbers" : "Mostrar o número das semanas",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
    "Primary CalDAV address" : "Endereço CalDAV primário",
    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV "
},
"nplurals=2; plural=(n > 1);");
